pub enum PreflightCheckError {
CommandExecution(Command, Error),
CommandUnsuccessful(Command, Output),
DefaultBasePathIO(PathBuf, Error),
TestUnderBasePathIO(PathBuf, Error),
}Variants
CommandExecution(Command, Error)
Happens when a required command (e.g. sshfs) cannot be executed.
CommandUnsuccessful(Command, Output)
Happens when a required command was executed, but was unsuccessful.
DefaultBasePathIO(PathBuf, Error)
Happens when the default mount path (e.g. /mnt/sshfs) does not exist and cannot be prepared.
TestUnderBasePathIO(PathBuf, Error)
Happens when a test directory (e.g. /mnt/sshfs/_sftpman_test_1234567890) under the default mount path could not be prepared.