pub enum SftpManError {
Generic(String),
NoMountsConfigDirectory,
MountListParse(ParseError),
FilesystemMountDefinitionRead(PathBuf, Error),
FilesystemMountDefinitionRemove(PathBuf, Error),
JSON(PathBuf, Error),
MountVfsTypeMismatch {
path: PathBuf,
found_vfs_type: String,
expected_vfs_type: String,
},
MountCommandBuilding(String),
CommandExecution(Command, Error),
CommandUnsuccessful(Command, Output),
IO(PathBuf, Error),
}Variants
Generic(String)
Happens when any other generic error occurs.
NoMountsConfigDirectory
Happens when the mounts configuration directory does not exist.
MountListParse(ParseError)
Happens when mnt::get_submounts fails to parse the mount list.
FilesystemMountDefinitionRead(PathBuf, Error)
Happens when the mount config definition cannot be read.
FilesystemMountDefinitionRemove(PathBuf, Error)
Happens when the mount config definition file cannot be removed.
JSON(PathBuf, Error)
Happens when the mount config definition cannot be parsed as JSON.
MountVfsTypeMismatch
Happens when a given mount path was found, but it was not of the expected type (e.g. fuse.sshfs).
MountCommandBuilding(String)
Happens when the mount command cannot be constructed.
CommandExecution(Command, Error)
Happens when the mount command cannot be executed.
CommandUnsuccessful(Command, Output)
Happens when the mount command was executed, but was unsuccessful.
IO(PathBuf, Error)
Happens when the mount directory could not be prepared.