Manager

Struct Manager 

pub struct Manager { /* private fields */ }

Implementations

Source

impl Manager

pub fn new() -> Result<Self, ManagerInitError>

pub fn definitions( &self, ) -> Result<Vec<FilesystemMountDefinition>, SftpManError>

Returns the list of all known (stored in the config directory) filesystem definitions.

pub fn definition( &self, id: &str, ) -> Result<FilesystemMountDefinition, SftpManError>

Returns the filesystem definition (as stored in the config directory) for the given ID.

pub fn full_state(&self) -> Result<Vec<MountState>, SftpManError>

Returns the full state (configuration and mount status) of all known (stored in the config directory) filesystem definitions.

pub fn is_definition_mounted( &self, definition: &FilesystemMountDefinition, ) -> Result<bool, SftpManError>

Tells if the given filesystem definition is currently mounted.

pub fn mount( &self, definition: &FilesystemMountDefinition, ) -> Result<(), SftpManError>

Mounts a filesystem definition unless already mounted.

pub fn umount( &self, definition: &FilesystemMountDefinition, ) -> Result<(), SftpManError>

Unmounts a filesystem definition (unless already unmounted) and removes its mount path from the filesystem hierarchy.

Unmounting is performed via a command call to fusermount3 -u .. (preferred) or fusermount -u .. (fallback), which may fail on filesystems that are currently busy. In such cases, a fallback is performed - the sshfs process responsible for the mount gets terminated.

pub fn remove( &self, definition: &FilesystemMountDefinition, ) -> Result<(), SftpManError>

Unmounts the given filesystem (if mounted) and removes the configuration file for it.

pub fn preflight_check(&self) -> Result<(), Vec<PreflightCheckError>>

Checks if we have everything needed to mount/unmount sshfs/SFTP filesystems.

pub fn persist( &self, definition: &FilesystemMountDefinition, ) -> Result<(), SftpManError>

Persists (creates or updates) a filesystem definition.

If the definition already exists, it will be unmounted before persisting and will be remounted after.

pub fn open( &self, definition: &FilesystemMountDefinition, ) -> Result<(), SftpManError>

Opens the directory where the given filesystem definition is mounted.